@@ -1,9 +1,9 @@
-/* $Id: options.c,v 1.42 2022/01/22 18:39:51 nanard Exp $ */
+/* $Id: options.c,v 1.43 2022/10/21 19:45:26 nanard Exp $ */
 /* vim: tabstop=4 shiftwidth=4 noexpandtab
  * MiniUPnP project
  * http://miniupnp.free.fr/ or https://miniupnp.tuxfamily.org/
  * author: Ryan Wagoner
- * (c) 2006-2021 Thomas Bernard
+ * (c) 2006-2022 Thomas Bernard
  * This software is subject to the conditions detailed
  * in the LICENCE file provided within the distribution */
 
@@ -320,6 +320,10 @@ freeoptions(void)
 	}
 	if(upnppermlist)
 	{
+		unsigned int i;
+		for (i = 0; i < num_upnpperm; i++) {
+			free_permission_line(upnppermlist + i);
+		}
 		free(upnppermlist);
 		upnppermlist = NULL;
 		num_upnpperm = 0;
